@@ -2,6 +2,7 @@ use std::mem::MaybeUninit;
 
 mod drop;
 mod index;
+mod from;
 
 #[derive(Debug)]
 /// A fixed-capacity vector that directly stores its elements  
@@ -22,6 +23,7 @@ impl<T, const N: usize> LocalVec<T, N> {
         }
     }
 
+    // TODO implement From<[T; N]> on top of this?
     pub fn from_array<const M: usize>(arr: [T; M]) -> Self {
         // TODO check at compile time
         assert!(M <= N, "can't store {} elements with a capacity of {}", M, N);
@@ -47,6 +49,10 @@ impl<T, const N: usize> LocalVec<T, N> {
         self.len
     }
 
+    pub unsafe fn set_len(&mut self, len: usize) {
+        self.len = len;
+    }
+
     pub fn capacity(&self) -> usize {
         N
     }
@@ -79,6 +85,16 @@ impl<T, const N: usize> LocalVec<T, N> {
         }
         debug_assert_eq!(self.len, 0);
     }
+
+    #[must_use = "consider using clear() instead"]
+    /// steal the elements stored
+    pub fn take_array(&mut self) -> [T; N] {
+        let arr: [T; N] = unsafe {
+            self.set_len(0);
+            std::mem::transmute_copy(&self.buf)
+        };
+        arr
+    }
 }
 
 #[cfg(test)]
@@ -191,4 +207,25 @@ mod tests {
 
         assert_eq!(vec.len(), 4);
     }
+
+    #[test]
+    fn test_set_len() {
+        let arr = [7; 4];
+        let mut vec = LocalVec::<_, 6>::from_array(arr);
+
+        assert_eq!(vec.len(), 4);
+        unsafe {
+            vec.set_len(1);
+        }
+        assert_eq!(vec.len(), 1);
+    }
+
+    #[test]
+    fn test_take_array() {
+        let arr = [7; 4];
+        let mut vec = LocalVec::<_, 6>::from_array(arr);
+        assert_eq!(vec.len(), 4);
+        let _ = vec.take_array();
+        assert_eq!(vec.len(), 0);
+    }
 }
